==> zen-cart-v1.2.0-l10n-jp-5.zip: zen-cart-v1.2.0-l10n-jp-5/admin/includes/languages/japanese/gv_sent.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
//  $Id: gv_sent.php,v 1.3 2004/11/20 07:23:11 shidairiki Exp $
//

define('HEADING_TITLE', 'եȷ');

define('TABLE_HEADING_SENDERS_NAME', '');
define('TABLE_HEADING_VOUCHER_VALUE', TEXT_GV_NAME . 'γ');
define('TABLE_HEADING_VOUCHER_CODE', TEXT_GV_REDEEM);
define('TABLE_HEADING_DATE_SENT', '');
define('TABLE_HEADING_ACTION', '');

define('TEXT_INFO_SENDERS_ID', 'ID:');
define('TEXT_INFO_AMOUNT_SENT', 'ճ:');
define('TEXT_INFO_DATE_SENT', ':');
define('TEXT_INFO_VOUCHER_CODE', TEXT_GV_REDEEM . ':');
define('TEXT_INFO_EMAIL_ADDRESS', '᡼륢ɥ쥹:');
define('TEXT_INFO_DATE_REDEEMED', ':');
define('TEXT_INFO_IP_ADDRESS', 'IP ɥ쥹:');
define('TEXT_INFO_CUSTOMERS_ID', 'ܵID:');
define('TEXT_INFO_NOT_REDEEMED', 'Ƥޤ');
?>

==> zen-cart-v1.3.0.2-l10n-jp-5.zip: zen-cart-v1.3.0.2-l10n-jp-5/admin/includes/languages/japanese/gv_sent.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
//  $Id: gv_sent.php 2388 2005-11-18 00:18:35Z ajeh $
//

define('HEADING_TITLE', TEXT_GV_NAMES . 'յϿ');

define('TABLE_HEADING_SENDERS_NAME', '');
define('TABLE_HEADING_VOUCHER_VALUE', TEXT_GV_NAME . 'γ');
define('TABLE_HEADING_VOUCHER_CODE', TEXT_GV_REDEEM);
define('TABLE_HEADING_DATE_SENT', '');
define('TEXT_HEADING_DATE_REDEEMED', 'λ');
define('TABLE_HEADING_ACTION', '');

define('TEXT_INFO_SENDERS_ID', 'ID:');
define('TEXT_INFO_AMOUNT_SENT', 'ճ:');
define('TEXT_INFO_DATE_SENT', ':');
define('TEXT_INFO_VOUCHER_CODE', TEXT_GV_REDEEM . ':');
define('TEXT_INFO_EMAIL_ADDRESS', '᡼륢ɥ쥹:');
define('TEXT_INFO_DATE_REDEEMED', ':');
define('TEXT_INFO_IP_ADDRESS', 'IP ɥ쥹:');
define('TEXT_INFO_CUSTOMERS_ID', 'ܵID:');
define('TEXT_INFO_NOT_REDEEMED', 'ޤƤޤ');
?>
